@@ -5,7 +5,7 @@ use std::convert::TryFrom;
 /// # Example
 ///
 /// ```
-/// use russell_openblas::*;
+/// use russell_openblas::to_i32;
 /// use std::convert::TryFrom;
 /// let m = 3_usize;
 /// let x = vec![0.0; m];
@@ -28,7 +28,7 @@ pub fn to_i32(num: usize) -> i32 {
 
 #[cfg(test)]
 mod tests {
-    use super::*;
+    use super::to_i32;
 
     #[test]
     fn usize_to_i32_works() {
